﻿using Client.eSAMMoHAddress;
using System;
using System.Net;

namespace Client
{
    class HiPing
    {
        public HiPing(String address, Boolean showIP, String server)
        {
            try
            {

                eSAMMoHAddress.eSAMMoHAddress_v01Client connection = new eSAMMoHAddress.eSAMMoHAddress_v01Client();
                if (server != null && server.Length > 0)
                {
                    //Override Server endpoint if specified by the user
                    connection.Endpoint.Address = new System.ServiceModel.EndpointAddress(server);
                }

                Console.WriteLine("Sending request: \"" + address + "\" to service " + connection.Endpoint.Address);

                //Establish connection
                connection.Open();    
 
                //Do web service call
                eSAMMoHAddress.AddressSuggestionType[] output;
                DateTime dt = DateTime.UtcNow;
                ResultHeaderType response = connection.SuggestAddress(address, "", 20, "test", "test", "test", out output);

                //Get the ping time
                Console.WriteLine("Response recieved: " + response.ResultCode + " in " + ((DateTime.UtcNow.Ticks - dt.Ticks) / 10000) + "ms");

                //Close connection, not even sure we need this.
                connection.Close();

                //Show the IP address, if specified by the user
                if (showIP)
                {
                    IPHostEntry ip = Dns.GetHostEntry(connection.Endpoint.Address.Uri.DnsSafeHost); 
                    if (ip.AddressList.Length == 0)
                    {
                        Console.WriteLine("Could not resolve IP address");
                    }
                    else
                    {
                        Console.WriteLine(ip.AddressList[0]);
                    }

                    Console.WriteLine(output.Length + " Results:");
                }

                //Print ping result
                foreach (AddressSuggestionType addr in output)
                {
                    Console.WriteLine(addr.FullAddress);
                }
            }

            //Generic Exceptions
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }
        }

        static void Main(string[] args)
            
        {

           // for (int i = 0; i < args.Length; i++)
           // {
           //     Console.WriteLine("arg: " + args[i]);
           // }
            //Flags
            Boolean useAddress = false;
            Boolean showIP = false;
            Boolean useServer = false;

            //Parameters to pass
            String address = "";
            String server = "";

            //Process them arguments!
            for (int i = 0; i < args.Length; i++)
            {
                //Address (mandatory)
                if (args[i] == "-a" && !useAddress)
                {
                    useAddress = true;
                    if (args.Length >= i+2)
                    {
                        address = args[++i];
                    }
                    else
                    {
                        //Console.WriteLine("Address not provided");
                        printInvalidUsage();

                    }

                }

                //IP (optional)
                if (args[i] == "-ip" && !showIP)
                {
                    showIP = true;
                }

                //Specify web service address (optional)
                if (args[i] == "-t" && !useServer)
                {
                    useServer = true;
                    if (args.Length >= i+2)
                    {
                        server = args[++i];
                    }
                    else
                    {
                        //Console.WriteLine("Server URL not provided");
                        printInvalidUsage();
                    }
                }
            }

            if (address == "")
            {
                printInvalidUsage();
            }





            new HiPing(address, showIP, server);
            exit();
        }

        private static void exit()
        {
            Console.WriteLine("\nPress any key to continue...");
            Console.ReadKey(true);
            Environment.Exit(0);
        }

        private static void printInvalidUsage()
        {
            Console.WriteLine("Invalid Parameters Provided\n");
            Console.WriteLine("Expected Usage: hiping-address.exe -a Address");
            Console.WriteLine("Mandatory:");
            Console.WriteLine("\t-a address Specified search address");
            Console.WriteLine("Optional:");
            Console.WriteLine("\t-t url Optional target eSAMMoHAddress Web Service server.");
            //Console.WriteLine("\t-ip Display Web Service server IP address.");
            
            exit();
        }



    }
}
